"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const errors_1 = require("./errors");
const options_1 = require("./options");
const guards_1 = require("../guards");
class BaseExecutor {
    constructor(namespace) {
        this.namespace = namespace;
    }
}
exports.BaseExecutor = BaseExecutor;
class Executor extends BaseExecutor {
    execute(argv, env) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const parsedArgs = options_1.parseArgs(argv, { boolean: true, string: '_' });
            const { args, obj } = yield this.namespace.locate(parsedArgs._);
            if (guards_1.isNamespace(obj)) {
                throw new errors_1.CommandNotFoundError('Command not found.', parsedArgs._);
            }
            const cmd = obj;
            const metadata = yield cmd.getMetadata();
            const options = options_1.parseArgs(argv, options_1.metadataToParseArgsOptions(metadata));
            yield cmd.validate(args);
            yield cmd.run(args, options);
        });
    }
}
exports.Executor = Executor;
function execute(namespace, argv, env) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const executor = new Executor(namespace);
        yield executor.execute(argv, env);
    });
}
exports.execute = execute;
